@@ -768,14 +768,6 @@ class Performance(object):
                 joint_prob[asset] = (1 / returns_length[asset]) * len(data.loc[(data.iloc[:,0] <= var_i[asset]) & (data.iloc[:,1] <= var_j[asset])])
                 margin_prob = int(round(threshold * returns_length[asset])) / returns_length[asset]
 
-
-        # return_len = len(return_i)
-        # var_i = value_at_risk(return_i, threshold)
-        # var_j = value_at_risk(return_j, threshold)
-        # data = pd.concat(return_i, return_j, axis = 1)
-        # joint_prob = (1 / return_len) * len(data.loc[(data.iloc[:,0] <= var_i) & (data.iloc[:,1] <= var_j)])
-        # margin_prob = int(round(threshold * return_len)) / return_len
-
         if uol == "lower":
             result = joint_prob / margin_prob
         if uol == "upper":
@@ -832,8 +824,8 @@ class Performance(object):
         spl_i = InterpolatedUnivariateSpline(data_i["x"], data_i["y"])
         spl_j = InterpolatedUnivariateSpline(data_j["x"], data_j["y"])
 
-        splcdf_i = spl_i(return_i)
-        splcdf_j = spl_j(return_j)
+        splcdf_i = np.clip(spl_i(return_i),1e-14,1)
+        splcdf_j = np.clip(spl_j(return_j),1e-14,1)
         max_list = []
         for i in range(length):
             max_list.append(max(splcdf_i[i], splcdf_j[i]))
